Once you run PGP_Reconstruction for this first time, this folder will receive a local copy of a slightly modified version of [MinPath](https://github.com/mgtools/MinPath), downloaded from a [external server](https://files.ufz.de/~umb-pgp_reconstruction-01/), and Prodigal, downloaded from [its official github repository](https://github.com/hyattpd/Prodigal/releases).